package org.jdtaus.core.messages;

import java.util.HashMap;
import java.util.Map;
import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

abstract class ExceptionMessageBundle{

private static final Map cache;

static
{
    cache = new HashMap();
    getInvalidObjectText(Locale.getDefault());
    getExceptionInfoText(Locale.getDefault());
    getErrorInfoText(Locale.getDefault());
    getNullMessageText(Locale.getDefault());
}

/** <pre> Missing fields in object stream.</pre>. */
public static String getInvalidObjectText(final Locale locale) {
    return getMessage("invalidObject", locale);
}

/** <pre> Missing fields in object stream.</pre>. */
public static MessageFormat getInvalidObjectMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("invalidObject", locale), locale);
}

/** <pre> A {1} occured.
{2}

</pre>. */
public static String getExceptionInfoText(final Locale locale) {
    return getMessage("exceptionInfo", locale);
}

/** <pre> A {1} occured.
{2}

</pre>. */
public static MessageFormat getExceptionInfoMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("exceptionInfo", locale), locale);
}

/** <pre> A {1} occured.
{2}

</pre>. */
public static String getErrorInfoText(final Locale locale) {
    return getMessage("errorInfo", locale);
}

/** <pre> A {1} occured.
{2}

</pre>. */
public static MessageFormat getErrorInfoMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("errorInfo", locale), locale);
}

/** <pre> No details available.</pre>. */
public static String getNullMessageText(final Locale locale) {
    return getMessage("nullMessage", locale);
}

/** <pre> No details available.</pre>. */
public static MessageFormat getNullMessageMessage(Locale locale) {
    if(locale == null) { locale = Locale.getDefault(); }
return new MessageFormat(getMessage("nullMessage", locale), locale);
}

private static String getMessage(final String key, Locale locale) {
    if(locale == null) {locale = Locale.getDefault(); }
    Map msgCache = (Map) cache.get(locale);
    if(msgCache == null)
    {
        msgCache = new HashMap();
        cache.put(locale, msgCache);
    }

    String msg = (String) msgCache.get(key);
    if(msg == null)
    {
        msg = ResourceBundle.getBundle(
        "org.jdtaus.core.messages.ExceptionMessage", locale).getString(key);
        msgCache.put(key, msg);
    };
    return msg;
}

}
